@@ -37,13 +37,14 @@ Print the titles of the unread entries::
 
 """
 
-__version__ = '0.22'
+__version__ = '1.9'
 
 
-from .core.reader import Reader, make_reader
+from .core import Reader, make_reader
 
-from .core.types import (
+from .types import (
     Feed,
+    ExceptionInfo,
     Entry,
     Content,
     Enclosure,
@@ -51,7 +52,7 @@ from .core.types import (
     HighlightedString,
 )
 
-from .core.exceptions import (
+from .exceptions import (
     ReaderError,
     FeedError,
     FeedExistsError,
@@ -70,6 +71,7 @@ from .core.exceptions import (
 
 # For internal use only.
 
+_CONFIG_ENVVAR = 'READER_CONFIG'
 _DB_ENVVAR = 'READER_DB'
 _PLUGIN_ENVVAR = 'READER_PLUGIN'
 _APP_PLUGIN_ENVVAR = 'READER_APP_PLUGIN'
